## 📂 `docs/` – The Agent's Knowledge Base (optional)

If your agent answers knowledge-based questions (FAQs, policies, etc.), you can put markdown, PDFs, or text files in this folder. Rasa can use this content for retrieval-augmented responses if set up with a vector store [2](https://rasa.com/docs/pro/build/retrieval-actions).

**Edit here** to update what your agent can retrieve and summarize for users.
